@@ -181,7 +181,7 @@ class MWCShellConfig(SetupTask):
 
     def run_task(self):
         with self.platform_rc_file().open('a') as fh:
-            result = run("which mwc", shell=True, check=True, capture_output=True)
+            result = run("which mwc", shell=True, check=True, text=True, capture_output=True)
             mwcpath = Path(result.stdout).parent
             fh.write(f"\n# MAKING WITH CODE\n")
             fh.write(f'export PATH="{mwcpath}:$PATH"\n')
